package cc.fascinated.bat.features.spotify.command;

import cc.fascinated.bat.command.BatSubCommand;
import cc.fascinated.bat.command.CommandInfo;
import cc.fascinated.bat.common.EmbedUtils;
import cc.fascinated.bat.event.EventListener;
import cc.fascinated.bat.features.spotify.SpotifyFeature;
import cc.fascinated.bat.features.spotify.profile.SpotifyProfile;
import cc.fascinated.bat.model.BatGuild;
import cc.fascinated.bat.model.BatUser;
import cc.fascinated.bat.service.SpotifyService;
import lombok.NonNull;
import net.dv8tion.jda.api.entities.Member;
import net.dv8tion.jda.api.entities.channel.middleman.MessageChannel;
import net.dv8tion.jda.api.events.interaction.ModalInteractionEvent;
import net.dv8tion.jda.api.events.interaction.component.ButtonInteractionEvent;
import net.dv8tion.jda.api.interactions.commands.SlashCommandInteraction;
import net.dv8tion.jda.api.interactions.components.ActionRow;
import net.dv8tion.jda.api.interactions.components.buttons.Button;
import net.dv8tion.jda.api.interactions.components.text.TextInput;
import net.dv8tion.jda.api.interactions.components.text.TextInputStyle;
import net.dv8tion.jda.api.interactions.modals.Modal;
import net.dv8tion.jda.api.interactions.modals.ModalMapping;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @author Fascinated (fascinated7)
 */
@Component
@CommandInfo(name = "pause", description = "Pause the current Spotify track")
public class PauseSubCommand extends BatSubCommand {
    private final SpotifyService spotifyService;

    @Autowired
    public PauseSubCommand(@NonNull SpotifyService spotifyService) {
        this.spotifyService = spotifyService;
    }

    @Override
    public void execute(BatGuild guild, @NonNull BatUser user, @NonNull MessageChannel channel, Member member, @NonNull SlashCommandInteraction interaction) {
        SpotifyProfile profile = user.getProfile(SpotifyProfile.class);
        if (!profile.hasLinkedAccount()) {
            interaction.replyEmbeds(SpotifyFeature.linkAccountEmbed()).queue();
            return;
        }

        if (!spotifyService.hasTrackPlaying(user)) {
            interaction.replyEmbeds(EmbedUtils.genericEmbed()
                            .setDescription("You need to be playing a track to pause it.")
                            .build())
                    .queue();
            return;
        }

        boolean didPause = spotifyService.pausePlayback(user);
        interaction.replyEmbeds(EmbedUtils.genericEmbed()
                        .setDescription(didPause ? "Paused the current track." : "The current track is already paused.")
                        .build())
                .queue();
    }
}
